@@ -1,16 +1,16 @@
 from ikea_api.constants import Constants as Constants
-from ikea_api.endpoints.auth import API as Auth
-from ikea_api.endpoints.cart import API as Cart
-from ikea_api.endpoints.ingka_items import API as IngkaItems
-from ikea_api.endpoints.iows_items import API as IowsItems
-from ikea_api.endpoints.order_capture import API as OrderCapture
+from ikea_api.endpoints.auth import Auth as Auth
+from ikea_api.endpoints.cart import Cart as Cart
+from ikea_api.endpoints.ingka_items import IngkaItems as IngkaItems
+from ikea_api.endpoints.iows_items import IowsItems as IowsItems
+from ikea_api.endpoints.order_capture import OrderCapture as OrderCapture
 from ikea_api.endpoints.order_capture import (
     convert_cart_to_checkout_items as convert_cart_to_checkout_items,
 )
-from ikea_api.endpoints.pip_item import API as PipItem
-from ikea_api.endpoints.purchases import API as Purchases
-from ikea_api.endpoints.search import API as Search
-from ikea_api.endpoints.stock import API as Stock
+from ikea_api.endpoints.pip_item import PipItem as PipItem
+from ikea_api.endpoints.purchases import Purchases as Purchases
+from ikea_api.endpoints.search import Search as Search
+from ikea_api.endpoints.stock import Stock as Stock
 from ikea_api.exceptions import APIError as APIError
 from ikea_api.exceptions import AuthError as AuthError
 from ikea_api.exceptions import GraphQLError as GraphQLError
@@ -20,7 +20,7 @@ from ikea_api.exceptions import NotSuccessError as NotSuccessError
 from ikea_api.exceptions import ParsingError as ParsingError
 from ikea_api.exceptions import ProcessingError as ProcessingError
 from ikea_api.exceptions import WrongItemCodeError as WrongItemCodeError
-from ikea_api.executors.httpx import run as run_async
+from ikea_api.executors.httpx import run_async as run_async
 from ikea_api.executors.requests import run as run
 from ikea_api.utils import format_item_code as format_item_code
 from ikea_api.utils import parse_item_codes as parse_item_codes
@@ -29,5 +29,3 @@ from ikea_api.wrappers.wrappers import get_delivery_services as get_delivery_ser
 from ikea_api.wrappers.wrappers import get_items as get_items
 from ikea_api.wrappers.wrappers import get_purchase_history as get_purchase_history
 from ikea_api.wrappers.wrappers import get_purchase_info as get_purchase_info
-
-# pyright: reportUnusedImport = false
